aboutsummaryrefslogtreecommitdiffstats
path: root/components/style/properties/helpers.mako.rs
diff options
context:
space:
mode:
Diffstat (limited to 'components/style/properties/helpers.mako.rs')
-rw-r--r--components/style/properties/helpers.mako.rs3
1 files changed, 2 insertions, 1 deletions
diff --git a/components/style/properties/helpers.mako.rs b/components/style/properties/helpers.mako.rs
index 4d3895440d5..7a25b2569ea 100644
--- a/components/style/properties/helpers.mako.rs
+++ b/components/style/properties/helpers.mako.rs
@@ -563,6 +563,7 @@
Copy,
Debug,
Eq,
+ FromPrimitive,
Hash,
MallocSizeOf,
Parse,
@@ -762,7 +763,7 @@
% endif
pub mod computed_value {
#[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
#[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss, ToResolvedValue)]
% if not extra_specified:
#[derive(Parse, SpecifiedValueInfo, ToComputedValue, ToShmem)]
% endif
@@ -762,7 +763,7 @@
pub mod computed_value {
#[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
- #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss, ToResolvedValue)]
+ #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, PartialEq, ToCss, ToResolvedValue)]
% if not extra_specified:
#[derive(Parse, SpecifiedValueInfo, ToComputedValue, ToShmem)]